@@ -311,6 +311,7 @@ void DkControlWidget::connectWidgets() {
 
 	// cropping
 	connect(cropWidget, SIGNAL(enterPressedSignal(DkRotatingRect, const QColor&)), viewport, SLOT(cropImage(DkRotatingRect, const QColor&)));
+	connect(cropWidget, SIGNAL(cancelSignal()), this, SLOT(hideCrop()));
 }
 
 void DkControlWidget::update() {
@@ -423,6 +424,11 @@ void DkControlWidget::showOverview(bool visible) {
 
 }
 
+void DkControlWidget::hideCrop(bool hide /* = true */) {
+
+	showCrop(!hide);
+}
+
 void DkControlWidget::showCrop(bool visible) {
 
 	if (visible && !editWidget->isVisible()) {
@@ -1689,13 +1695,13 @@ void DkViewPort::loadFile(QFileInfo file, bool silent) {
 
 void DkViewPort::reloadFile() {
 
-	unloadImage();
-
 	if (loader) {
-		loader->changeFile(0, false, DkImageLoader::cache_force_load);	// silent loading, but force loading
-
 		if (controller->getFilePreview())
-			controller->getThumbPool()->setFile(loader->getFile(), true);
+			controller->getThumbPool()->setFile(loader->getFile(), DkThumbsLoader::user_updated);
+
+		unloadImage();
+
+		loader->changeFile(0, false, DkImageLoader::cache_force_load);	// silent loading, but force loading
 	}
 }
 
@@ -2543,6 +2549,9 @@ void DkViewPortContrast::setImage(QImage newImg) {
 
 	DkViewPort::setImage(newImg);
 
+	if (newImg.isNull())
+		return;
+
 	if (imgStorage.getImage().format() == QImage::Format_Indexed8) {
 		int format = imgStorage.getImage().format();
 		imgs = QVector<QImage>(1);
